==> s-i18n-extract-0.0.1-2.tgz: package/Extractor.js <==
const chalk = require('chalk');
const glob = require('glob');
const fs = require('fs');
const babylon = require('babylon');

/**
 * Extractor class
 */
export class Extractor {
  constructor(config) {
    this.config = config;

    this.verbose =
      typeof config.verbose !== 'undefined' ? !!config.verbose : false;
  }
  /**
   * Tells if a directory exists
   * 
   * @param {string} directory The tested directory
   */
  directoryExists(directory) {
    try {
      fs.statSync(directory);
      return true;
    } catch (e) {}
    return false;
  }
  /**
   * Logs an error message and exits the current process
   * 
   * @param {string} message The error message
   */
  fatal(message) {
    console.error(`${chalk.red('error')} ${message}`);
    // process.exit(1);
  }
  /**
   * Prints a message, if in verbose mode
   * 
   * @param {*} message The message
   */
  report(message) {
    if (this.verbose) {
      console.log(message);
    }
  }
  /**
   * Scans the source file and extracts messages to be translated
   */
  extractFromSource() {
    const messages = {};

    this.config.sourcePath.forEach(
      function(source) {
        let files = glob.sync(source + '/**/*.js', { debug: false });

        files.forEach(
          function(file) {
            for (let i = 0; i < this.config.ignorePath.length; i++) {
              // console.log(file, this.config.ignorePath[i]);
              if (file.indexOf(this.config.ignorePath[i]) !== -1) {
                return;
              }
            }

            let contents = fs.readFileSync(file).toString();
            const tokens = babylon.parse(contents, { sourceType: 'module' })
              .tokens;
            let counter = 0;

            for (let i = 0; i < tokens.length; i++) {
              const token = tokens[i];
              if (
                token.type.label === 'name' &&
                token.value === this.config.translator
              ) {
                const parenthesis = tokens[i + 1];
                const message = tokens[i + 2];

                if (!parenthesis || parenthesis.type.label !== '(') {
                  continue;
                }

                if (!message || message.type.label !== 'string') {
                  continue;
                }

                if (messages[message.value] === '') {
                  continue;
                }

                counter++;
                messages[message.value] = '';
              }
            }

            this.report(
              ` - parsing ${chalk.bold(file)} .. ${chalk.bold(
                counter
              )} strings found!\n`
            );
          }.bind(this)
        );
      }.bind(this)
    );

    return messages;
  }

  /**
   * 
   * @param {*} messages 
   */
  generateFiles(messages) {
    this.report('Generating translations:');

    let exports = '/* eslint-disable quote-props */\nexport default {\n';

    this.config.languages.forEach(
      function(language) {
        let filepath = `${process.cwd()}/${this.config
          .messagePath}/${language}.json`;

        let oldMessages = {};
        try {
          oldMessages = require(filepath);
        } catch (e) {
          console.log(e);
        }

        let action =
          oldMessages && oldMessages.length === 0 ? 'generated' : 'merged';

        // Get a fresh copy of found strings
        var newMessages = { ...messages };

        // Iterate on old strings
        Object.keys(oldMessages).forEach(function(key) {
          if (typeof newMessages[key] !== 'undefined') {
            // Translation needed & found: copy it
            newMessages[key] = oldMessages[key];
          } else {
            // Translation old & gone: surround it with @
            newMessages[key] =
              '@' + oldMessages[key].replace(/^@+|@+$/g, '') + '@';
          }
        });

        // Write the new message file
        fs.writeFile(
          filepath,
          JSON.stringify(newMessages, null, 2),
          'utf8',
          function(err) {
            if (err) throw err;
          }
        );
        this.report(` - ${action} ${chalk.bold(filepath)}`);
        exports += `  '${language}': require('./${language}.json'),\n`;
      }.bind(this)
    );

    exports += '};\n';

    fs.writeFile(
      `${process.cwd()}/${this.config.messagePath}/index.js`,
      exports,
      'utf8',
      function(err) {
        if (err) throw err;
      }
    );
  }

  /**
   * Extracts messages to be translated from the source code
   * 
   * @return {boolean} TRUE on success
   */
  extractMessages() {
    this.report(
      `Extracting messages in ${chalk.green(
        this.config.sourcePath
      )} using ${chalk.green(this.config.translator + '()')}`
    );

    let messages = this.extractFromSource();
    this.report('Done parsing\n');

    this.generateFiles(messages);
    this.report('Done, have fun translating!\n'); // Et voilà!

    return true;
  }
}

==> s-i18n-extract-0.0.1-3.tgz: package/Extractor.js <==
const chalk = require('chalk');
const glob = require('glob');
const fs = require('fs');
const babylon = require('babylon');

/**
 * Extractor class
 */
module.exports = class Extractor {
  constructor(config) {
    this.config = config;

    this.verbose =
      typeof config.verbose !== 'undefined' ? !!config.verbose : false;
  }
  /**
   * Tells if a directory exists
   * 
   * @param {string} directory The tested directory
   */
  directoryExists(directory) {
    try {
      fs.statSync(directory);
      return true;
    } catch (e) {}
    return false;
  }
  /**
   * Logs an error message and exits the current process
   * 
   * @param {string} message The error message
   */
  fatal(message) {
    console.error(`${chalk.red('error')} ${message}`);
    // process.exit(1);
  }
  /**
   * Prints a message, if in verbose mode
   * 
   * @param {*} message The message
   */
  report(message) {
    if (this.verbose) {
      console.log(message);
    }
  }
  /**
   * Scans the source file and extracts messages to be translated
   */
  extractFromSource() {
    const messages = {};

    this.config.sourcePath.forEach(
      function(source) {
        let files = glob.sync(source + '/**/*.js', { debug: false });

        files.forEach(
          function(file) {
            for (let i = 0; i < this.config.ignorePath.length; i++) {
              // console.log(file, this.config.ignorePath[i]);
              if (file.indexOf(this.config.ignorePath[i]) !== -1) {
                return;
              }
            }

            let contents = fs.readFileSync(file).toString();
            const tokens = babylon.parse(contents, { sourceType: 'module' })
              .tokens;
            let counter = 0;

            for (let i = 0; i < tokens.length; i++) {
              const token = tokens[i];
              if (
                token.type.label === 'name' &&
                token.value === this.config.translator
              ) {
                const parenthesis = tokens[i + 1];
                const message = tokens[i + 2];

                if (!parenthesis || parenthesis.type.label !== '(') {
                  continue;
                }

                if (!message || message.type.label !== 'string') {
                  continue;
                }

                if (messages[message.value] === '') {
                  continue;
                }

                counter++;
                messages[message.value] = '';
              }
            }

            this.report(
              ` - parsing ${chalk.bold(file)} .. ${chalk.bold(
                counter
              )} strings found!\n`
            );
          }.bind(this)
        );
      }.bind(this)
    );

    return messages;
  }

  /**
   * 
   * @param {*} messages 
   */
  generateFiles(messages) {
    this.report('Generating translations:');

    let exports = '/* eslint-disable quote-props */\nexport default {\n';

    this.config.languages.forEach(
      function(language) {
        let filepath = `${process.cwd()}/${this.config
          .messagePath}/${language}.json`;

        let oldMessages = {};
        try {
          oldMessages = require(filepath);
        } catch (e) {
          console.log(e);
        }

        let action =
          oldMessages && oldMessages.length === 0 ? 'generated' : 'merged';

        // Get a fresh copy of found strings
        var newMessages = { ...messages };

        // Iterate on old strings
        Object.keys(oldMessages).forEach(function(key) {
          if (typeof newMessages[key] !== 'undefined') {
            // Translation needed & found: copy it
            newMessages[key] = oldMessages[key];
          } else {
            // Translation old & gone: surround it with @
            newMessages[key] =
              '@' + oldMessages[key].replace(/^@+|@+$/g, '') + '@';
          }
        });

        // Write the new message file
        fs.writeFile(
          filepath,
          JSON.stringify(newMessages, null, 2),
          'utf8',
          function(err) {
            if (err) throw err;
          }
        );
        this.report(` - ${action} ${chalk.bold(filepath)}`);
        exports += `  '${language}': require('./${language}.json'),\n`;
      }.bind(this)
    );

    exports += '};\n';

    fs.writeFile(
      `${process.cwd()}/${this.config.messagePath}/index.js`,
      exports,
      'utf8',
      function(err) {
        if (err) throw err;
      }
    );
  }

  /**
   * Extracts messages to be translated from the source code
   * 
   * @return {boolean} TRUE on success
   */
  extractMessages() {
    this.report(
      `Extracting messages in ${chalk.green(
        this.config.sourcePath
      )} using ${chalk.green(this.config.translator + '()')}`
    );

    let messages = this.extractFromSource();
    this.report('Done parsing\n');

    this.generateFiles(messages);
    this.report('Done, have fun translating!\n'); // Et voilà!

    return true;
  }
};
